@@ -223,14 +223,15 @@ class Curve:
                 highestIv = self.markIvs[idx]
                 highestStrike = self.strikes[idx]
 
-        # print(
-        #     highestIv,
-        #     highestStrike,
-        #     lowestIv,
-        #     lowestStrike,
-        #     self.putCall,
-        #     should_reverse,
-        # )
+        print(
+            self.strikes,
+            highestIv,
+            highestStrike,
+            lowestIv,
+            lowestStrike,
+            self.putCall,
+            should_reverse,
+        )
         # print(self.strikes, self.markIvs)
         if lowestStrike == 0:
             return self.markIvs[idx]
